summaryrefslogtreecommitdiffstats
path: root/src/plugins/platforms/ios/qioswindow.mm
diff options
context:
space:
mode:
authorTor Arne Vestbø <tor.arne.vestbo@digia.com>2013-11-07 12:20:28 +0100
committerThe Qt Project <gerrit-noreply@qt-project.org>2013-11-08 07:20:08 +0100
commit24d1f584146c487c1bc16a8191c2c472da6c6f2b (patch)
tree3d50227b3b343951b068f6af52fc49da32bfa126 /src/plugins/platforms/ios/qioswindow.mm
parenta301e868f7a24a7b98b22623b01be92488527c8d (diff)
iOS: Rename QIOSWindow's backing view from EAGLView to QUIView
Matches the cocoa QNSView and highlights the relation to UIView. Change-Id: Idcdb17bff994c1e0aef099400c21915a7041e44c Reviewed-by: Richard Moe Gustavsen <richard.gustavsen@digia.com>
Diffstat (limited to 'src/plugins/platforms/ios/qioswindow.mm')
-rw-r--r--src/plugins/platforms/ios/qioswindow.mm12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/plugins/platforms/ios/qioswindow.mm b/src/plugins/platforms/ios/qioswindow.mm
index 9eba049f95..2cb3fe86e1 100644
--- a/src/plugins/platforms/ios/qioswindow.mm
+++ b/src/plugins/platforms/ios/qioswindow.mm
@@ -58,7 +58,7 @@
#include <QtDebug>
-@interface EAGLView : UIView <UIKeyInput>
+@interface QUIView : UIView <UIKeyInput>
{
@public
UITextAutocapitalizationType autocapitalizationType;
@@ -83,7 +83,7 @@
@end
-@implementation EAGLView
+@implementation QUIView
+ (Class)layerClass
{
@@ -305,8 +305,8 @@
- (QWindow *)qwindow
{
- if ([self isKindOfClass:[EAGLView class]])
- return static_cast<EAGLView *>(self)->m_qioswindow->window();
+ if ([self isKindOfClass:[QUIView class]])
+ return static_cast<QUIView *>(self)->m_qioswindow->window();
return nil;
}
@@ -316,7 +316,7 @@ QT_BEGIN_NAMESPACE
QIOSWindow::QIOSWindow(QWindow *window)
: QPlatformWindow(window)
- , m_view([[EAGLView alloc] initWithQIOSWindow:this])
+ , m_view([[QUIView alloc] initWithQIOSWindow:this])
, m_normalGeometry(QPlatformWindow::geometry())
, m_windowLevel(0)
, m_devicePixelRatio(1.0)
@@ -392,7 +392,7 @@ void QIOSWindow::setGeometry(const QRect &rect)
// Since we don't support transformations on the UIView, we can set the frame
// directly and let UIKit deal with translating that into bounds and center.
// Changing the size of the view will end up in a call to -[EAGLView layoutSubviews]
// which will update QWindowSystemInterface with the new size.
m_view.frame = toCGRect(rect);
}
@@ -392,7 +392,7 @@ void QIOSWindow::setGeometry(const QRect &rect)
// Since we don't support transformations on the UIView, we can set the frame
// directly and let UIKit deal with translating that into bounds and center.
- // Changing the size of the view will end up in a call to -[EAGLView layoutSubviews]
+ // Changing the size of the view will end up in a call to -[QUIView layoutSubviews]
// which will update QWindowSystemInterface with the new size.
m_view.frame = toCGRect(rect);